@@ -415,8 +415,11 @@ htp_status_t htp_connp_RES_BODY_CHUNKED_LENGTH(htp_connp_t *connp) {
             fprint_raw_data(stderr, "Chunk length line", data, len);
             #endif
 
-            connp->out_chunked_length = htp_parse_chunked_length(data, len);
-
+            int chunk_ext = 0;
+            connp->out_chunked_length = htp_parse_chunked_length(data, len, &chunk_ext);
+            if (chunk_ext == 1) {
+                htp_log(connp, HTP_LOG_MARK, HTP_LOG_WARNING, 0, "Request chunk extension");
+            }
             // empty chunk length line, lets try to continue
             if (connp->out_chunked_length == -1004) {
                 connp->out_current_consume_offset = connp->out_current_read_offset;
@@ -613,7 +616,6 @@ htp_status_t htp_connp_RES_BODY_DETERMINE(htp_connp_t *connp) {
         if (is100continue) {
             if (connp->out_tx->seen_100continue != 0) {
                 htp_log(connp, HTP_LOG_MARK, HTP_LOG_ERROR, 0, "Already seen 100-Continue.");
-                return HTP_ERROR;
             }
 
             // Ignore any response headers seen so far.
@@ -1076,6 +1078,12 @@ htp_status_t htp_connp_RES_LINE(htp_connp_t *connp) {
             // data as a response body because that is what browsers do.
            
             if (htp_treat_response_line_as_body(data, len)) {
+                // if we have a next line beginning with H, skip this one
+                if (connp->out_current_read_offset+1 < connp->out_current_len && (connp->out_current_data[connp->out_current_read_offset] == 'H' || len <= 2)) {
+                    connp->out_tx->response_ignored_lines++;
+                    htp_connp_res_clear_buffer(connp);
+                    return HTP_OK;
+                }
                 connp->out_tx->response_content_encoding_processing = HTP_COMPRESSION_NONE;
 
                 connp->out_current_consume_offset = connp->out_current_read_offset;
