@@ -300,7 +300,7 @@ int64_t htp_parse_content_length(bstr *b, htp_connp_t *connp) {
  * @param[in] len
  * @return Chunk length, or a negative number on error.
  */
-int64_t htp_parse_chunked_length(unsigned char *data, size_t len) {
+int64_t htp_parse_chunked_length(unsigned char *data, size_t len, int *extension) {
     // skip leading line feeds and other control chars
     while (len) {
         unsigned char c = *data;
@@ -323,6 +323,16 @@ int64_t htp_parse_chunked_length(unsigned char *data, size_t len) {
     }
     // cut off trailing junk
     if (i != len) {
+        if (extension) {
+            size_t j = i;
+            while (j < len) {
+                if (data[j] == ';') {
+                    *extension = 1;
+                    break;
+                }
+                j++;
+            }
+        }
         len = i;
     }
 
@@ -435,7 +445,11 @@ void htp_log(htp_connp_t *connp, const char *file, int line, enum htp_log_level_
     log->code = code;
     log->msg = strdup(buf);
 
-    htp_list_add(connp->conn->messages, log);
+    if (htp_list_add(connp->conn->messages, log) != HTP_OK) {
+        free((void *) log->msg);
+        free(log);
+        return;
+    }
 
     if (level == HTP_LOG_ERROR) {
         connp->last_error = log;
@@ -2510,7 +2524,7 @@ void htp_uri_free(htp_uri_t *uri) {
     free(uri);
 }
 
-htp_uri_t *htp_uri_alloc() {
+htp_uri_t *htp_uri_alloc(void) {
     htp_uri_t *u = calloc(1, sizeof (htp_uri_t));
     if (u == NULL) return NULL;
 
